==> otyacraftengine-fabric-2.1-build2-sources.jar: dev/felnull/otyacraftengine/fabric/client/handler/ModelResourceHandler.java <==
package dev.felnull.otyacraftengine.fabric.client.handler;

import ModelProviderException;
import dev.felnull.otyacraftengine.client.event.OEClientEventHooks;
import dev.felnull.otyacraftengine.fabric.client.model.OBJLoader;
import net.fabricmc.fabric.api.client.model.*;
import net.minecraft.class_1091;
import net.minecraft.class_1100;
import net.minecraft.class_2960;
import org.jetbrains.annotations.Nullable;
import var;

public class ModelResourceHandler implements ModelResourceProvider, ModelVariantProvider {
    public static void init() {
        var h = new ModelResourceHandler();
        ModelLoadingRegistry.INSTANCE.registerResourceProvider(n -> h);
        ModelLoadingRegistry.INSTANCE.registerVariantProvider(n -> h);
    }

    @Override
    public @Nullable class_1100 loadModelResource(class_2960 resourceId, ModelProviderContext context) {
        try {
            if (OEClientEventHooks.onFabricOBJLoader(resourceId))
                return OBJLoader.getInstance().loadModel(new class_2960(resourceId.method_12836(), "models/" + resourceId.method_12832()));
        } catch (Exception ex) {
            ex.printStackTrace();
        }
        return null;
    }

    @Override
    public @Nullable class_1100 loadModelVariant(class_1091 modelId, ModelProviderContext context) throws ModelProviderException {
        try {
            if (OEClientEventHooks.onFabricOBJLoader(modelId))
                return OBJLoader.getInstance().loadModel(new class_2960(modelId.method_12836(), "models/" + modelId.method_12832()));
        } catch (Exception ex) {
            ex.printStackTrace();
        }
        return null;
    }
}

==> otyacraftengine-fabric-2.10-build2-sources.jar: dev/felnull/otyacraftengine/fabric/client/handler/ModelResourceHandler.java <==
package dev.felnull.otyacraftengine.fabric.client.handler;

import dev.felnull.otyacraftengine.client.entrypoint.OEClientEntryPointManager;
import dev.felnull.otyacraftengine.client.event.OEClientEventHooks;
import dev.felnull.otyacraftengine.fabric.client.model.OBJLoader;
import net.fabricmc.fabric.api.client.model.*;
import net.minecraft.class_1091;
import net.minecraft.class_1100;
import net.minecraft.class_2960;
import net.minecraft.class_3300;
import org.jetbrains.annotations.Nullable;
import var;
import java.util.function.Consumer;

public class ModelResourceHandler implements ModelResourceProvider, ModelVariantProvider, ExtraModelProvider {
    public static void init() {
        var h = new ModelResourceHandler();
        ModelLoadingRegistry.INSTANCE.registerResourceProvider(n -> h);
        ModelLoadingRegistry.INSTANCE.registerVariantProvider(n -> h);
        ModelLoadingRegistry.INSTANCE.registerModelProvider(h);
    }

    @Override
    public @Nullable class_1100 loadModelResource(class_2960 resourceId, ModelProviderContext context) {
        try {
            if (OEClientEventHooks.onFabricOBJLoader(resourceId))
                return OBJLoader.getInstance().loadModel(new class_2960(resourceId.method_12836(), "models/" + resourceId.method_12832()));
        } catch (Exception ex) {
            ex.printStackTrace();
        }
        return null;
    }

    @Override
    public @Nullable class_1100 loadModelVariant(class_1091 modelId, ModelProviderContext context) {
        try {
            if (OEClientEventHooks.onFabricOBJLoader(modelId))
                return OBJLoader.getInstance().loadModel(new class_2960(modelId.method_12836(), "models/" + modelId.method_12832()));
        } catch (Exception ex) {
            ex.printStackTrace();
        }
        return null;
    }

    @Override
    public void provideExtraModels(class_3300 manager, Consumer<class_2960> out) {
        OEClientEntryPointManager.getInstance().call().onModelRegistry(out);
    }
}
